StakeCache

Struct StakeCache 

pub struct StakeCache(pub Arc<RwLock<StakeCacheData>>);
A cache of stake and validator accounts.

This wraps StakeCacheData in Arc<RwLock<...>> to allow thread-safe shared access during parallel transaction execution. The Arc allows the same data to be shared between the Bank and StakesHandle, so mutations to pending stake data by builtin programs are visible to the Bank.

Tuple Fields

0: Arc<RwLock<StakeCacheData>>

Implementations

Source

impl StakeCache

pub fn new() -> Self

Create a new empty stake cache.

pub fn with_data(data: StakeCacheData) -> Self

Create a stake cache with the given data.

pub fn from_arc(arc: Arc<RwLock<StakeCacheData>>) -> Self

Create a stake cache from an existing Arc (for sharing references).

pub fn arc_clone(&self) -> Arc<RwLock<StakeCacheData>>

Get a clone of the inner Arc for sharing.