pub struct StakeCache(pub Arc<RwLock<StakeCacheData>>);Expand description
A cache of stake and validator accounts.
This wraps StakeCacheData in Arc<RwLock<...>> to allow thread-safe shared
access during parallel transaction execution. The Arc allows the same data
to be shared between the Bank and StakesHandle, so mutations to pending
stake data by builtin programs are visible to the Bank.
Tuple Fields
0: Arc<RwLock<StakeCacheData>>Implementations
Sourceimpl StakeCache
impl StakeCache
Sourcepub fn with_data(data: StakeCacheData) -> Self
pub fn with_data(data: StakeCacheData) -> Self
Create a stake cache with the given data.
Sourcepub fn from_arc(arc: Arc<RwLock<StakeCacheData>>) -> Self
pub fn from_arc(arc: Arc<RwLock<StakeCacheData>>) -> Self
Create a stake cache from an existing Arc (for sharing references).
Sourcepub fn arc_clone(&self) -> Arc<RwLock<StakeCacheData>>
pub fn arc_clone(&self) -> Arc<RwLock<StakeCacheData>>
Get a clone of the inner Arc for sharing.